# Introduction 
This library is for extracting feature from face image (face feature, align face, face quality)
# Getting Started
TODO: Guide users through getting your code up and running on their own system. In this section you can talk about:
<!-- 1.	Installation process
2.	Software dependencies
3.	Latest releases
4.	API references -->

# Build and Test
TODO: Describe and show how to build your code and run the tests. 

## rebuild
```
python setup.py bdist_wheel
```
## install dependencies:
```
pip install -r requirements.txt
```

## install lib

```
pip install dist/facefeaturelib-0.1.0-py3-none-any.whl
```

## test
change image file path in file test.py
copy folder facefeaturelib/onnx để lấy model onnx
```
python test.py
```

# Contribute
TODO: Explain how other users and developers can contribute to make your code better. 
